
package Paws::WAF::DeleteWebACL;
  use Moose;
  has ChangeToken => (is => 'ro', isa => 'Str', required => 1);
  has WebACLId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteWebACL');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::WAF::DeleteWebACLResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WAF::DeleteWebACL - Arguments for method DeleteWebACL on L<Paws::WAF>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteWebACL on the
L<AWS WAF|Paws::WAF> service. Use the attributes of this class
as arguments to method DeleteWebACL.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteWebACL.

=head1 SYNOPSIS

    my $waf = Paws->service('WAF');
    # To delete a web ACL
    # The following example deletes a web ACL with the ID
    # example-46da-4444-5555-example.
    my $DeleteWebACLResponse = $waf->DeleteWebACL(
      {
        'ChangeToken' => 'abcd12f2-46da-4fdb-b8d5-fbd4c466928f',
        'WebACLId'    => 'example-46da-4444-5555-example'
      }
    );

    # Results:
    my $ChangeToken = $DeleteWebACLResponse->ChangeToken;

    # Returns a L<Paws::WAF::DeleteWebACLResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/waf/DeleteWebACL>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ChangeToken => Str

The value returned by the most recent call to GetChangeToken.



=head2 B<REQUIRED> WebACLId => Str

The C<WebACLId> of the WebACL that you want to delete. C<WebACLId> is
returned by CreateWebACL and by ListWebACLs.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteWebACL in L<Paws::WAF>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

