package Paws::Glue::CatalogImportStatus;
  use Moose;
  has ImportCompleted => (is => 'ro', isa => 'Bool');
  has ImportedBy => (is => 'ro', isa => 'Str');
  has ImportTime => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::CatalogImportStatus

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Glue::CatalogImportStatus object:

  $service_obj->Method(Att1 => { ImportCompleted => $value, ..., ImportTime => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Glue::CatalogImportStatus object:

  $result = $service_obj->Method(...);
  $result->Att1->ImportCompleted

=head1 DESCRIPTION

A structure containing migration status information.

=head1 ATTRIBUTES


=head2 ImportCompleted => Bool

  True if the migration has completed, or False otherwise.


=head2 ImportedBy => Str

  The name of the person who initiated the migration.


=head2 ImportTime => Str

  The time that the migration was started.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

