
package Paws::SimpleWorkflow::RecordActivityTaskHeartbeat;
  use Moose;
  has Details => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'details' );
  has TaskToken => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'taskToken' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RecordActivityTaskHeartbeat');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SimpleWorkflow::ActivityTaskStatus');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SimpleWorkflow::RecordActivityTaskHeartbeat - Arguments for method RecordActivityTaskHeartbeat on L<Paws::SimpleWorkflow>

=head1 DESCRIPTION

This class represents the parameters used for calling the method RecordActivityTaskHeartbeat on the
L<Amazon Simple Workflow Service|Paws::SimpleWorkflow> service. Use the attributes of this class
as arguments to method RecordActivityTaskHeartbeat.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RecordActivityTaskHeartbeat.

=head1 SYNOPSIS

    my $swf = Paws->service('SimpleWorkflow');
    my $ActivityTaskStatus = $swf->RecordActivityTaskHeartbeat(
      TaskToken => 'MyTaskToken',
      Details   => 'MyLimitedData',    # OPTIONAL
    );

    # Results:
    my $CancelRequested = $ActivityTaskStatus->CancelRequested;

    # Returns a L<Paws::SimpleWorkflow::ActivityTaskStatus> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/swf/RecordActivityTaskHeartbeat>

=head1 ATTRIBUTES


=head2 Details => Str

If specified, contains details about the progress of the task.



=head2 B<REQUIRED> TaskToken => Str

The C<taskToken> of the ActivityTask.

C<taskToken> is generated by the service and should be treated as an
opaque value. If the task is passed to another process, its
C<taskToken> must also be passed. This enables it to provide its
progress and respond with results.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RecordActivityTaskHeartbeat in L<Paws::SimpleWorkflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

