
package Paws::SES::UpdateTemplateResponse;
  use Moose;

  has _request_id => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SES::UpdateTemplateResponse

=head1 ATTRIBUTES


=head2 _request_id => Str


=cut

