
package Paws::ElasticBeanstalk::CreateStorageLocationResultMessage;
  use Moose;
  has S3Bucket => (is => 'ro', isa => 'Str');

  has _request_id => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::CreateStorageLocationResultMessage

=head1 ATTRIBUTES


=head2 S3Bucket => Str

The name of the Amazon S3 bucket created.


=head2 _request_id => Str


=cut

