package Paws::MediaConvert::OutputDetail;
  use Moose;
  has DurationInMs => (is => 'ro', isa => 'Int', request_name => 'durationInMs', traits => ['NameInRequest']);
  has VideoDetails => (is => 'ro', isa => 'Paws::MediaConvert::VideoDetail', request_name => 'videoDetails', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::MediaConvert::OutputDetail

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::MediaConvert::OutputDetail object:

  $service_obj->Method(Att1 => { DurationInMs => $value, ..., VideoDetails => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::MediaConvert::OutputDetail object:

  $result = $service_obj->Method(...);
  $result->Att1->DurationInMs

=head1 DESCRIPTION

Details regarding output

=head1 ATTRIBUTES


=head2 DurationInMs => Int

  Duration in milliseconds


=head2 VideoDetails => L<Paws::MediaConvert::VideoDetail>

  



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::MediaConvert>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

