
package Paws::AutoScaling::CreateOrUpdateTags;
  use Moose;
  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::AutoScaling::Tag]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateOrUpdateTags');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::CreateOrUpdateTags - Arguments for method CreateOrUpdateTags on L<Paws::AutoScaling>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateOrUpdateTags on the
L<Auto Scaling|Paws::AutoScaling> service. Use the attributes of this class
as arguments to method CreateOrUpdateTags.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateOrUpdateTags.

=head1 SYNOPSIS

    my $autoscaling = Paws->service('AutoScaling');
    # To create or update tags for an Auto Scaling group
    # This example adds two tags to the specified Auto Scaling group.
    $autoscaling->CreateOrUpdateTags(
      {
        'Tags' => [

          {
            'Key'               => 'Role',
            'PropagateAtLaunch' => true,
            'ResourceId'        => 'my-auto-scaling-group',
            'ResourceType'      => 'auto-scaling-group',
            'Value'             => 'WebServer'
          },

          {
            'Key'               => 'Dept',
            'PropagateAtLaunch' => true,
            'ResourceId'        => 'my-auto-scaling-group',
            'ResourceType'      => 'auto-scaling-group',
            'Value'             => 'Research'
          }
        ]
      }
    );


Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/autoscaling/CreateOrUpdateTags>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Tags => ArrayRef[L<Paws::AutoScaling::Tag>]

One or more tags.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateOrUpdateTags in L<Paws::AutoScaling>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

