
package Paws::IoT::DescribeCACertificate;
  use Moose;
  has CertificateId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'caCertificateId', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCACertificate');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/cacertificate/{caCertificateId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::DescribeCACertificateResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::DescribeCACertificate - Arguments for method DescribeCACertificate on L<Paws::IoT>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCACertificate on the
L<AWS IoT|Paws::IoT> service. Use the attributes of this class
as arguments to method DescribeCACertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCACertificate.

=head1 SYNOPSIS

    my $iot = Paws->service('IoT');
    my $DescribeCACertificateResponse = $iot->DescribeCACertificate(
      CertificateId => 'MyCertificateId',

    );

    # Results:
    my $CertificateDescription =
      $DescribeCACertificateResponse->CertificateDescription;
    my $RegistrationConfig = $DescribeCACertificateResponse->RegistrationConfig;

    # Returns a L<Paws::IoT::DescribeCACertificateResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iot/DescribeCACertificate>

=head1 ATTRIBUTES


=head2 B<REQUIRED> CertificateId => Str

The CA certificate identifier.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCACertificate in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

