
package Paws::Inspector::RegisterCrossAccountAccessRole;
  use Moose;
  has RoleArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'roleArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RegisterCrossAccountAccessRole');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Inspector::RegisterCrossAccountAccessRole - Arguments for method RegisterCrossAccountAccessRole on L<Paws::Inspector>

=head1 DESCRIPTION

This class represents the parameters used for calling the method RegisterCrossAccountAccessRole on the
L<Amazon Inspector|Paws::Inspector> service. Use the attributes of this class
as arguments to method RegisterCrossAccountAccessRole.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RegisterCrossAccountAccessRole.

=head1 SYNOPSIS

    my $inspector = Paws->service('Inspector');
    # Register cross account access role
    # Registers the IAM role that Amazon Inspector uses to list your EC2
    # instances at the start of the assessment run or when you call the
    # PreviewAgents action.
    $inspector->RegisterCrossAccountAccessRole(
      {
        'RoleArn' => 'arn:aws:iam::123456789012:role/inspector'
      }
    );


Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/inspector/RegisterCrossAccountAccessRole>

=head1 ATTRIBUTES


=head2 B<REQUIRED> RoleArn => Str

The ARN of the IAM role that grants Amazon Inspector access to AWS
Services needed to perform security assessments.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RegisterCrossAccountAccessRole in L<Paws::Inspector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

