
package Paws::Firehose::TagDeliveryStreamOutput;
  use Moose;

  has _request_id => (is => 'ro', isa => 'Str');

### main pod documentation begin ###

=head1 NAME

Paws::Firehose::TagDeliveryStreamOutput

=head1 ATTRIBUTES


=head2 _request_id => Str


=cut

1;