
package Paws::Inspector::DescribeCrossAccountAccessRole;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCrossAccountAccessRole');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Inspector::DescribeCrossAccountAccessRoleResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeCrossAccountAccessRole - Arguments for method DescribeCrossAccountAccessRole on L<Paws::Inspector>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCrossAccountAccessRole on the
L<Amazon Inspector|Paws::Inspector> service. Use the attributes of this class
as arguments to method DescribeCrossAccountAccessRole.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCrossAccountAccessRole.

=head1 SYNOPSIS

    my $inspector = Paws->service('Inspector');
    # Describte cross account access role
    # Describes the IAM role that enables Amazon Inspector to access your AWS
    # account.
    my $DescribeCrossAccountAccessRoleResponse =
      $inspector->DescribeCrossAccountAccessRole();

    # Results:
    my $registeredAt = $DescribeCrossAccountAccessRoleResponse->registeredAt;
    my $roleArn      = $DescribeCrossAccountAccessRoleResponse->roleArn;
    my $valid        = $DescribeCrossAccountAccessRoleResponse->valid;

  # Returns a L<Paws::Inspector::DescribeCrossAccountAccessRoleResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/inspector/DescribeCrossAccountAccessRole>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCrossAccountAccessRole in L<Paws::Inspector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

