
package Paws::API::Response;
  use Moose;
  has _request_id => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::API::Response

=head1 ATTRIBUTES

=head2 _request_id => Str

=cut

